@@ -43,7 +43,7 @@ class Muse:
             self.target_name = target_name
         elif self.target_name is None:
             print("No target name specified")
-            return
+            return None
 
         mf = MuseFinder()
         self.loop.run_until_complete(mf.search_for_muses(timeout=self.timeout))
@@ -51,7 +51,7 @@ class Muse:
 
         if len(self.all_muses) < 1:
             print("No MUSEs found, please try again or increase the timeout")
-            return
+            return None
         else:
             found = False
             for d in self.all_muses:
@@ -61,7 +61,7 @@ class Muse:
                     found = True
             if found is False:
                 print("Couldn't find target, + " + str(self.target_name) + ". Try again or increase the timeout.")
-                return
+                return None
 
         # Connecting
         push_eeg = partial(self._push, offset=EEG_PORT_OFFSET)
@@ -71,15 +71,17 @@ class Muse:
         self.muse = MuseBLE(client=self.target_muse, callback_control=self._command_callback,
                             callback_acc=push_acc, callback_eeg=push_eeg, callback_gyro=push_gyro,
                             callback_ppg=push_ppg)
-
-        self.loop.run_until_complete(self.muse.connect(timeout=30))
-
+        try:
+            self.loop.run_until_complete(self.muse.connect(timeout=30))
+        except asyncio.exceptions.TimeoutError:
+            print ("30 second time out reached, cannot connect to MUSE! Ty again...")
+            return None
         print("connection was successful")
         _ = self.pullACC()
         _ = self.pullEEG()
         _ = self.pullGyro()
         _ = self.pullPPG()
-        return
+        return self
 
     def pullEEG(self):
         self.loop.run_until_complete(self.muse.start())
